/* Copyright (C) 2009 Papavasileiou Dimitris                             
 *                                                                      
 * This program is free software: you can redistribute it and/or modify 
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation, either version 3 of the License, or    
 * (at your option) any later version.                                  
 *                                                                      
 * This program is distributed in the hope that it will be useful,      
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        
 * GNU General Public License for more details.                         
 *                                                                      
 * You should have received a copy of the GNU General Public License    
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef _TEXTURE_H_
#define _TEXTURE_H_

#include <lua.h>
#include <GL/gl.h>

#include "object.h"

@interface Texture: Object {
    int size[3];
    GLuint name;
}

-(Texture *) initWithPixels: (unsigned char *) pixels
                     ofSize: (int[3]) n
           andLevelsBetween: (int) base
	                and: (int) max;
-(int) width;
-(int) height;
-(int) components;
-(GLuint) index;

@end

#endif
